################################################################################
################################################################################

### Computing metrics about Camera data

### By: Jono Handley, jonorow@gmail.com

################################################################################
################################################################################


################################################################################
### Set up environment
################################################################################

## Load required libraries
library(zoo)
library(xts) 
library(signal) ## For interpolation
library(lubridate) ## For time objects
library(plyr) ## To rename columns
library(data.table)

## Will adjust the number of decimal places displayed and help deal with split second issues
options(digits.secs=4)
#options(digits=0)

################################################################################
### Read in ALL merged CAM annotations from when the bird departed and which include prey detail
################################################################################

## Set you working directory
setwd("~/PhD/WriteUp/WriteUp_Data Chapters/Chapter 5_Behaviour/Chap 5_Supp Data and Code")

## Get your data
#load("DepID21_2013_VidAtSea.R") # For an individual deployment
load("AllTrips_VidAtSea.R") # For all deployments

## Rename data
d <- d.temp

## Check
head(d,2)
tail(d,2)

dim(d)

table(d$PreyEvent)

## See how many unique values you have for each column
sapply(d, function(x) length(unique(x)))
## See what those unique values are for behavioural categories:
result <- sapply(d[,6:15], function(x) unique(x))
result



##############################
## Create column of Unique feeding events
##############################

## Paste together unique combinations of prey events and feeding detail
d$Feed <- paste(d$PreyEvent,d$PreyEventDetail,d$Capture,d$LikelyPrey,d$Orientation, sep=" ")
table(d$Feed)
summary(d)

## Look at only when feeding events occured
d2 <- subset(d, d$PreyEvent==1)
head(d2)
d2 <- droplevels(d2)
table(d2$Feed)

## Determine the number of specific feeding events, rather than the number of frames (as above)
d$sep <- rleid(d$PreyEvent)
head(d,2)
dat1 <- subset(d, d$PreyEvent==1)
head(dat1,2)
dat1$sep2 <- rleid(dat1$sep)
head(dat1,2)

## Extract just the top row so you can look at individual feeding events
rm(temp.feed)
temp.feed <- data.frame()
for(i in 1:length(unique(dat1$sep2))){
  d <- subset(dat1, dat1$sep2== i)
  d2 <- d[1,]
  temp.feed <- rbind(temp.feed,d2)
}

head(temp.feed)
dim(temp.feed)

## Look at the feeding events
t <- table(temp.feed$Feed)
t
t2 <- data.frame(t)
t2
## Save as a csv file for pivot table use in excel
write.csv(t2,file=paste("FeedEventsOverView.csv",sep=""),row.names=F)
write.csv(temp.feed,file=paste("Individual_FeedEventsOverView.csv",sep=""),row.names=F)


################################################################################
################################################################################
## Duration of feeding events
################################################################################
################################################################################
## First, get data frame back as original loaded
d <- d.temp
## Paste together unique combos of prey events and feeding detail
d$Feed <- paste(d$PreyEvent,d$PreyEventDetail,d$Capture,d$LikelyPrey,d$Orientation, sep=" ")
head(d,2)


############################
## LK (lobster krill) feeding duration
d$UniqueFeed <- rleid(d$PreyEvent)
## Subset out relevant PC data
LK.data <- subset(d, d$PreyEventDetail=="LK")
## Now apply the rleid function again BUT TO NEW COLUMMN
LK.data$UniqueFeedingEvent <- rleid(LK.data$UniqueFeed)
## Check 
head(LK.data)
## Loop over each feeding event
temp.LK <- data.frame()

for(LK in 1: max(LK.data$UniqueFeedingEvent)){
  LK.dat <- subset(LK.data, LK.data$UniqueFeedingEvent==LK)
  FeedDuration <- max(LK.dat$TripTime_s)-min(LK.dat$TripTime_s)
  LK.dat2 <- data.frame(Deployment = LK.dat$Deployment[1], Colony = LK.dat$Colony[1], Prey = LK.dat$Feed[1], FeedDuration_s = FeedDuration )
  ## rbind files together
  temp.LK <- rbind(temp.LK,LK.dat2) 
}

temp.LK


################################################################################
################################################################################
## Time to first feeding
################################################################################
################################################################################

temp.feed
head(temp.feed,2)
temp.feed$DeploymentNumber <- rleid(temp.feed$Deployment)

rm(temp.data2)
temp.data2 <- data.frame()

for(j in 1:max(temp.feed$DeploymentNumber)){

  #j=23
  data <- subset(temp.feed, temp.feed$DeploymentNumber== j)
  ## Get first row
  data2 <- data[1,]
  
  ## Extract categorical variables
  Deployment <- data$Deployment[1]
  Colony <- data$Colony[1]
  Season <- data$Season[1]
  
  ##############################
  ## Calculate when first feeding event occured (time is in seconds)
  ##############################
  FirstFeed <- data2$TripTime_s
  
  ##############################
  ## And what it was
  Prey <- data2$PreyEventDetail[1]
  
  FeedEvent <- data.frame(Deployment, Colony, Season, FirstFeed_mins = FirstFeed, Prey = Prey)
  ## rbind files together
  temp.data2 <- rbind(temp.data2,FeedEvent) 
}

temp.data2
#d <- temp.data2[complete.cases(temp.data2),]
